module.exports = defineTest({
	description: 'side-effects in pattern defaults should not be ignored'
});
